@@ -55,8 +55,8 @@ var languageNames = {
 "si": "Singhalesisch",
 "sk": "Slowakisch",
 "sl": "Slowenisch",
-"dsb": "Sorbian (Lower)",
-"hsb": "Sorbian (Upper)",
+"dsb": "Niedersorbisch",
+"hsb": "Obersorbisch",
 "es": "Spanisch",
 "sv": "Schwedisch",
 "tg": "Tadschikisch",
